@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: xml-conduit
-version: 1.3.4.1
-id: xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
-key: xmlco_54jcCUs4cOt5ju4vV8jYF4
+version: 1.3.4
+id: xml-conduit-1.3.4-978b9ab149c55d47c395c4e421ee22a7
+key: xmlco_Is0wkxVmnS566BcT8bqkkE
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -19,27 +19,27 @@ exposed-modules:
     Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
 hidden-modules: Text.XML.Stream.Token
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.4.1
-hs-libraries: HSxml-conduit-1.3.4.1-54jcCUs4cOt5ju4vV8jYF4
+import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
+library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.4
+data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.4
+hs-libraries: HSxml-conduit-1.3.4-Is0wkxVmnS566BcT8bqkkE
 depends:
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
-    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
+    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
-    conduit-extra-1.1.13.1-49d5b7e57d33a6d70b83744864ccf557
+    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
+    conduit-extra-1.1.11-c734df1add5fd1001eeb71b770cb5cb3
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
-    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    xml-types-0.3.6-d2b0c720c0578e3ecc104b3af950ac90
+    xml-types-0.3.6-c95586b34c41769092e7d9cdd505a61e
 haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
 haddock-html: /usr/share/doc/haskell-xml-conduit/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
